%define eclipse_base     %{_datadir}/eclipse
%define gcj_support      1

Name:      eclipse-phpeclipse
Version:   1.2.1
Release:   2%{?dist}
Summary:   PHP Eclipse plugin
Group:     Development/Tools
License:   CPL
URL:       http://phpeclipse.net/

# source tarball and the script used to generate it from upstream's source control
# script usage:
# $ sh get-phpeclipse.sh
Source0:   phpeclipse-%{version}.tar.gz
Source1:   get-phpeclipse.sh

Patch0:    %{name}-broken-help-links.patch
Patch1:    %{name}-fix-build-props.patch
Patch2:    %{name}-httpd-integration.patch
Patch3:    %{name}-no-htmlparser.patch
Patch4:    %{name}-rm-win32-help.patch
Patch5:    %{name}-external-parser.patch
Patch6:    %{name}-external-preview.patch

BuildRoot: %{_tmppath}/%{name}-%{version}-%{release}-root-%(%{__id_u} -n)

%if %{gcj_support}
BuildRequires:    gcc-java
BuildRequires:    java-gcj-compat-devel
Requires(post):   java-gcj-compat
Requires(postun): java-gcj-compat
%else
BuildArch:        noarch
%endif
BuildRequires:    java-devel
BuildRequires:    jpackage-utils
BuildRequires:    eclipse-pde >= 1:3.3
Requires:         java
Requires:         jpackage-utils
Requires:         eclipse-platform >= 1:3.3
Requires:         php >= 5
Requires:         php-pecl-xdebug
Requires:         httpd

%description
PHPEclipse is an open source PHP IDE based on the Eclipse platform. Features
supported include syntax highlighting, content assist, PHP manual integration,
templates and support for the XDebug and DBG debuggers.

%prep
%setup -q -n phpeclipse-%{version}

# apply patches
%patch0 -p4
%patch1 -p4
%patch2 -p4
%patch3 -p4
%patch4 -p4
%patch5 -p4
%patch6 -p4

# ditch bundled libs in favor of building against fedora packaged libs
#rm net.sourceforge.phpeclipse.phpmanual.htmlparser/sax2.jar \
#   net.sourceforge.phpeclipse.phpmanual.htmlparser/htmllexer.jar \
#   net.sourceforge.phpeclipse.phpmanual.htmlparser/filterbuilder.jar \
#   net.sourceforge.phpeclipse.phpmanual.htmlparser/thumbelina.jar \
#   net.sourceforge.phpeclipse.phpmanual.htmlparser/junit.jar \
#   net.sourceforge.phpeclipse.phpmanual.htmlparser/htmlparser.jar
#build-jar-repository -s -p net.sourceforge.phpeclipse.phpmanual.htmlparser xml-commons-apis

#grep -lR sax2 * | xargs sed --in-place "s/sax2/xml-commons-apis/"

# fix jar versions
find -name MANIFEST.MF | xargs sed --in-place "s/0.0.0/%{version}/"

# make sure upstream hasn't sneaked in any jars we don't know about
JARS=""
for j in `find -name "*.jar"`; do
  if [ ! -L $j ]; then
    JARS="$JARS $j"
  fi
done
if [ ! -z "$JARS" ]; then
   echo "These jars should be deleted and symlinked to system jars: $JARS"
   exit 1
fi

%build
# prepare pdebuild environment
/bin/sh -x %{eclipse_base}/buildscripts/copy-platform SDK %{eclipse_base}
mkdir home
SDK=$(cd SDK > /dev/null && pwd)
homedir=$(cd home > /dev/null && pwd)

# build the main feature
java -cp $SDK/startup.jar \
  -Dosgi.sharedConfiguration.area=%{_libdir}/eclipse/configuration \
  org.eclipse.core.launcher.Main \
  -application org.eclipse.ant.core.antRunner \
  -Dtype=feature \
  -Did=net.sourceforge.phpeclipse.feature \
  -DbaseLocation=$SDK \
  -DsourceDirectory=$(pwd) \
  -DbuildDirectory=$(pwd)/build \
  -Dbuilder=%{eclipse_base}/plugins/org.eclipse.pde.build/templates/package-build \
  -f %{eclipse_base}/plugins/org.eclipse.pde.build/scripts/build.xml \
  -vmargs -Duser.home=$homedir

# build the debug features
java -cp $SDK/startup.jar \
  -Dosgi.sharedConfiguration.area=%{_libdir}/eclipse/configuration \
  org.eclipse.core.launcher.Main \
  -application org.eclipse.ant.core.antRunner \
  -Dtype=feature \
  -Did=net.sourceforge.phpeclipse.debug.feature \
  -DbaseLocation=$SDK \
  -DsourceDirectory=$(pwd) \
  -DbuildDirectory=$(pwd)/build \
  -Dbuilder=%{eclipse_base}/plugins/org.eclipse.pde.build/templates/package-build \
  -f %{eclipse_base}/plugins/org.eclipse.pde.build/scripts/build.xml \
  -vmargs -Duser.home=$homedir
java -cp $SDK/startup.jar \
  -Dosgi.sharedConfiguration.area=%{_libdir}/eclipse/configuration \
  org.eclipse.core.launcher.Main \
  -application org.eclipse.ant.core.antRunner \
  -Dtype=feature \
  -Did=net.sourceforge.phpeclipse.xdebug.feature \
  -DbaseLocation=$SDK \
  -DsourceDirectory=$(pwd) \
  -DbuildDirectory=$(pwd)/build \
  -Dbuilder=%{eclipse_base}/plugins/org.eclipse.pde.build/templates/package-build \
  -f %{eclipse_base}/plugins/org.eclipse.pde.build/scripts/build.xml \
  -vmargs -Duser.home=$homedir

%install
rm -rf %{buildroot}
install -d -m 755 %{buildroot}%{eclipse_base}
unzip -q -d %{buildroot}%{eclipse_base}/.. build/rpmBuild/net.sourceforge.phpeclipse.feature.zip
unzip -q -d %{buildroot}%{eclipse_base}/.. build/rpmBuild/net.sourceforge.phpeclipse.debug.feature.zip
unzip -q -d %{buildroot}%{eclipse_base}/.. build/rpmBuild/net.sourceforge.phpeclipse.xdebug.feature.zip

# need to recreate the symlinks to libraries that were setup in "prep"
# because for some reason the ant copy task doesn't preserve them
#pushd %{buildroot}%{eclipse_base}/plugins/net.sourceforge.phpeclipse.phpmanual.htmlparser_*
#rm *.jar
#build-jar-repository -s -p . xml-commons-apis
#popd

%if %{gcj_support}
%{_bindir}/aot-compile-rpm
%endif

%clean
rm -rf %{buildroot}

%if %{gcj_support}
%post -p %{_bindir}/rebuild-gcj-db
%postun -p %{_bindir}/rebuild-gcj-db
%endif

%files
%defattr(-,root,root,-)

# main feature
%doc %{eclipse_base}/features/net.sourceforge.phpeclipse.feature_*/cpl-v10.html
%{eclipse_base}/features/net.sourceforge.phpeclipse.feature_*/feature.xml
%{eclipse_base}/features/net.sourceforge.phpeclipse.feature_*/license.html
%{eclipse_base}/features/net.sourceforge.phpeclipse.feature_*/phpeclipse.jpeg
%dir %{eclipse_base}/features/net.sourceforge.phpeclipse.feature_*
%{eclipse_base}/plugins/net.sourceforge.phpeclipse_*
%{eclipse_base}/plugins/net.sourceforge.phpeclipse.core_*
%{eclipse_base}/plugins/net.sourceforge.phpeclipse.externaltools_*
%{eclipse_base}/plugins/net.sourceforge.phpeclipse.help_*
%{eclipse_base}/plugins/net.sourceforge.phpeclipse.phphelp_*
%{eclipse_base}/plugins/net.sourceforge.phpeclipse.phpmanual_*
#%{eclipse_base}/plugins/net.sourceforge.phpeclipse.phpmanual.htmlparser_*
%{eclipse_base}/plugins/net.sourceforge.phpeclipse.smarty.ui_*
%{eclipse_base}/plugins/net.sourceforge.phpeclipse.ui_*
%{eclipse_base}/plugins/net.sourceforge.phpeclipse.webbrowser_*
%{eclipse_base}/plugins/net.sourceforge.phpeclipse.xml.core_*
%{eclipse_base}/plugins/net.sourceforge.phpeclipse.xml.ui_*

# debug features
%{eclipse_base}/features/net.sourceforge.phpeclipse.debug.feature_*
%{eclipse_base}/plugins/net.sourceforge.phpeclipse.debug.core_*
%{eclipse_base}/plugins/net.sourceforge.phpeclipse.debug.ui_*
%{eclipse_base}/plugins/net.sourceforge.phpeclipse.launching_*
%{eclipse_base}/features/net.sourceforge.phpeclipse.xdebug.feature_*
%{eclipse_base}/plugins/net.sourceforge.phpeclipse.xdebug.core_*
%{eclipse_base}/plugins/net.sourceforge.phpeclipse.xdebug.ui_*

%if %{gcj_support}
%{_libdir}/gcj/%{name}
%endif

%changelog
* Sun Nov 16 2008 Mat Booth <fedora@matbooth.co.uk> 1.2.1-2
- Add php-pecl-xdebug dependency.

* Fri Nov 14 2008 Mat Booth <fedora@matbooth.co.uk> 1.2.1-1
- Update to 1.2.1 and rebase patches.
- Fixes mark occurances bug in Eclipse 3.4 (#706).
- Fix NPE on shutdown if external tools are not used.

* Sun Jun 29 2008 Mat Booth <fedora@matbooth.co.uk> 1.2.0-0.2.svn1573
- Add patch for Show External Preview functionality.
- Add patch for Use External PHP Parser functionality.

* Sat Jun 28 2008 Mat Booth <fedora@matbooth.co.uk> 1.2.0-0.1.svn1573
- New maintainer.
- Update to version 1.2.0 pre-release, svn1573.
- Adapt patches to new version.
- Update package for new Eclipse plugin guidelines.

* Sat Oct 20 2007 Brandon Holbrook <fedora at theholbrooks.org> 1.1.8-17
- Reference php5 instead of php4 in httpd.conf [bug 314831]

* Mon Dec 18 2006 Brandon Holbrook <fedora at theholbrooks.org> 1.1.8-16
- Require eclipse-pde-runtime

* Mon Dec 18 2006 Brandon Holbrook <fedora at theholbrooks.org> 1.1.8-15
- Own gcj/eclipse-phpeclipse/
- dos2unix cpl-v10.html

* Mon Dec 18 2006 Brandon Holbrook <fedora at theholbrooks.org> 1.1.8-13
- Replace datadir with libdir in sharedConfiguration to match new eclipse

* Tue Nov 28 2006 Brandon Holbrook <fedora at theholbrooks.org> 1.1.8-12
- Added -Dosgi.sharedConfiguration.area to build command

* Mon Nov 27 2006 Brandon Holbrook <fedora at theholbrooks.org> 1.1.8-11
- Removed maximum version Requirement for eclipse-platform

* Mon Nov 27 2006 Brandon Holbrook <fedora at theholbrooks.org> 1.1.8-10
- New java command to fix broken builds

* Thu Nov  2 2006 Brandon Holbrook <fedora at theholbrooks.org> 1.1.8-9
- Use included .html file as %%doc

* Tue Oct 31 2006 Brandon Holbrook <fedora at theholbrooks.org> 1.1.8-8
- New maintainer
- Fix Group, License, and Description
- Include a copy of the CPL-1.0

* Fri Aug 18 2006 Ben Konrath <bkonrath@redhat.com> 1.1.8-7
- Make external tools plugin re-locatable. 
- Enable GCJ support for Fedora.

* Fri Aug 18 2006 Ben Konrath <bkonrath@redhat.com> 1.1.8-6
- Use httpd.conf from external tools plugin instead of workspace to work around
  a race condition in the main phpeclipse plugin.

* Tue Aug 15 2006 Ben Konrath <bkonrath@redhat.com> 1.1.8-5
- Do not start httpd automatically in httpd integration patch.

* Fri Aug 11 2006 Ben Konrath <bkonrath@redhat.com> 1.1.8-4
- Add httpd integration patch.
- Move linux external tool preferences and httpd.conf to the httpd-integration
  patch.
- Remove README for httpd integration.
- Add patch to remove win32 help preferences.
- Add patch to compile against Eclipse SDK 3.2.

* Mon May 15 2006 Ben Konrath <bkonrath@redhat.com> 1.1.8-3
- Add preferences for the external tools on linux.
- Add README for httpd integration.

* Fri May 12 2006 Ben Konrath <bkonrath@redhat.com> 1.1.8-2
- Add requires.

* Wed Apr 26 2006 Ben Konrath <bkonrath@redhat.com> 1.1.8-1
- initial version
